/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.examples.mailreaderjpa;

import java.util.ArrayList;
import java.util.List;
import javax.faces.model.SelectItem;
import org.apache.mailreaderjpa.Protocol;
import org.apache.mailreaderjpa.Subscription;
import org.apache.mailreaderjpa.User;
import org.apache.shale.view.AbstractApplicationBean;

/**
 * <p>Application scope bean containing cached domain lists and other
 * application wide information.  In addition, it includes code to bootstrap
 * the database contents if this is the very first time that newly created
 * database tables are accessed.</p>
 */
public class Domains extends AbstractApplicationBean {


    // ------------------------------------------------------- Public Properties


    /**
     * <p>The business {@link Logic} for this application.  This value
     * will be injected, based on the managed bean configuration.</p>
     */
    private Logic logic = null;


    /**
     * <p>Return the business {@link Logic} for this application.</p>
     */
    public Logic getLogic() {
        return this.logic;
    }


    /**
     * <p>Set the business {@link Logic} for this application.</p>
     *
     * @param logic The new business logic instance
     */
    public void setLogic(Logic logic) {
        this.logic = logic;
    }


    /**
     * <p>The array of <code>SelectItem</code> instances identifying the valid
     * mail protocols for this application.</p>
     */
    private SelectItem[] protocols;


    /**
     * <p>Return an array of select items for valid protocols.</p>
     */
    public SelectItem[] getProtocols() {

        return this.protocols;

    }


    // -------------------------------------------------------- Lifecycle Events


    /**
     * <p>Initialize the <code>profiles</codes> list from the database.  If
     * necessary, bootstrap the database content if it is completely empty.</p>
     */
    public void init() {

        log("Caching application wide static data");
        try {

            // Ensure that the database content has been bootstrapped
            getLogic().bootstrap();

            // Assemble the value of the "protocols" array
            List<Protocol> items = getLogic().getProtocols();
            protocols = new SelectItem[items.size()];
            int n = 0;
            for (Protocol item : items) {
                protocols[n++] = new SelectItem(item, item.getDescription());
            }

        } catch (Exception e) {

            log("Exception acquiring domain data", e);
            error("Exception acquiring domain data: " + e);
            getFacesContext().responseComplete();

        }


    }


}
